[hornetq-commits] JBoss hornetq SVN: r12045 - in trunk: hornetq-core/src/main/java/org/hornetq/api/core and 3 other directories.

do-not-reply at jboss.org do-not-reply at jboss.org
Mon Jan 23 07:01:44 EST 2012


Author: borges
Date: 2012-01-23 07:01:43 -0500 (Mon, 23 Jan 2012)
New Revision: 12045

Modified:
   trunk/hornetq-commons/src/main/java/org/hornetq/api/core/PropertyConversionException.java
   trunk/hornetq-core/src/main/java/org/hornetq/api/core/Interceptor.java
   trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientMessage.java
   trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientProducer.java
   trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/HornetQClient.java
   trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ServerLocator.java
   trunk/hornetq-jms/src/main/java/org/hornetq/api/jms/management/ConnectionFactoryControl.java
   trunk/hornetq-jms/src/main/java/org/hornetq/jms/client/HornetQConnectionFactory.java
Log:
HORNETQ-829 Public API javadoc fixes: broken references (and other javadoc corrections)

Modified: trunk/hornetq-commons/src/main/java/org/hornetq/api/core/PropertyConversionException.java
===================================================================
--- trunk/hornetq-commons/src/main/java/org/hornetq/api/core/PropertyConversionException.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-commons/src/main/java/org/hornetq/api/core/PropertyConversionException.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -14,13 +14,10 @@
 package org.hornetq.api.core;
 
 /**
- * A PropertyConversionException is thrown by Message methods
- * when a property can not be converted to the expected type.
- *
+ * A PropertyConversionException is thrown by {@link org.hornetq.api.core.Message} methods when a
+ * property can not be converted to the expected type.
  * @author <a href="mailto:jmesnil at redhat.com">Jeff Mesnil</a>
- *
- * @see Message
- *
+ * @see org.hornetq.api.core.Message
  */
 public class PropertyConversionException extends RuntimeException
 {

Modified: trunk/hornetq-core/src/main/java/org/hornetq/api/core/Interceptor.java
===================================================================
--- trunk/hornetq-core/src/main/java/org/hornetq/api/core/Interceptor.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-core/src/main/java/org/hornetq/api/core/Interceptor.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -13,16 +13,15 @@
 
 package org.hornetq.api.core;
 
-import org.hornetq.api.core.client.ClientSessionFactory;
+import org.hornetq.api.core.client.ServerLocator;
 import org.hornetq.core.protocol.core.Packet;
 import org.hornetq.spi.core.protocol.RemotingConnection;
 
 /**
  * This is class is a simple way to intercepting calls on HornetQ client and servers.
  * <p/>
- * To add an interceptor to HornetQ server, you have to modify hornetq-configuration.xml.
- * To add it to a client, use {@link ClientSessionFactory#addInterceptor(Interceptor)}
- *
+ * To add an interceptor to HornetQ server, you have to modify hornetq-configuration.xml. To add it
+ * to a client, use {@link ServerLocator#addInterceptor(Interceptor)}
  * @author clebert.suconic at jboss.com
  * @author <a href="mailto:tim.fox at jboss.com">Tim Fox</a>
  */

Modified: trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientMessage.java
===================================================================
--- trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientMessage.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientMessage.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -92,8 +92,6 @@
     * Sets the body's IntputStream. 
     * <br> 
     * This method is used when sending large messages
-    * 
-    * @throws HornetQException
     */
    void setBodyInputStream(InputStream bodyInputStream);
 

Modified: trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientProducer.java
===================================================================
--- trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientProducer.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ClientProducer.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -18,19 +18,21 @@
 import org.hornetq.api.core.SimpleString;
 
 /**
- * A ClientProducer is used to send messages to a specific address. Messages are then routed on the server to any queues
- * that are bound to the address. A ClientProducer can either be created with a specific address in mind or with none.
- * With the latter the address must be provided using the appropriate send() method.  <br><br>
- *
- * The sending semantics can change depending on what blocking semantics are set via {@link ClientSessionFactory#setBlockOnDurableSend(boolean)}
- * and {@link org.hornetq.api.core.client.ClientSessionFactory#setBlockOnNonDurableSend(boolean)} . If set to true
- * then for each message type, durable and non durable respectively, any exceptions such as the address not existing or
- * security exceptions will be thrown at the time of send. Alternatively if set to false then exceptions will only be
- * logged on the server.      <br><br>
- *
- * The send rate can also be controlled via {@link ClientSessionFactory#setProducerMaxRate(int)}
- * and the {@link org.hornetq.api.core.client.ClientSessionFactory#setProducerWindowSize(int)}. <br><br>
- *
+ * A ClientProducer is used to send messages to a specific address. Messages are then routed on the
+ * server to any queues that are bound to the address. A ClientProducer can either be created with a
+ * specific address in mind or with none. With the latter the address must be provided using the
+ * appropriate send() method. <br>
+ * <p>
+ * The sending semantics can change depending on what blocking semantics are set via
+ * {@link ServerLocator#setBlockOnDurableSend(boolean)} and
+ * {@link org.hornetq.api.core.client.ServerLocator#setBlockOnNonDurableSend(boolean)} . If set to
+ * true then for each message type, durable and non durable respectively, any exceptions such as the
+ * address not existing or security exceptions will be thrown at the time of send. Alternatively if
+ * set to false then exceptions will only be logged on the server. <br>
+ * <p>
+ * The send rate can also be controlled via {@link ServerLocator#setProducerMaxRate(int)} and the
+ * {@link org.hornetq.api.core.client.ServerLocator#setProducerWindowSize(int)}. <br>
+ * <br>
  * @author <a href="mailto:tim.fox at jboss.com">Tim Fox</a>
  * @author <a href="mailto:ataylor at redhat.com">Andy Taylor</a>
  */
@@ -41,33 +43,32 @@
     *
     * <br><br>The address can be <code>null</code> if the ClientProducer
     *
-    * was creating without specifying an address, that is by using {@link ClientSession#createProducer()}. 
-    * 
+    * was creating without specifying an address, that is by using {@link ClientSession#createProducer()}.
+    *
     * @return the address where messages will be sent
     */
    SimpleString getAddress();
 
    /**
-    * Sends a message to an address.
-    *
-    * specified in {@link ClientSession#createProducer(String)} or similar methods.
-    *
-    * <br><br>This will block until confirmation that the message has reached the server has been received if
-    * {@link ClientSessionFactory#setBlockOnDurableSend(boolean)} or {@link org.hornetq.api.core.client.ClientSessionFactory#setBlockOnNonDurableSend(boolean)}
-    * are set to <code>true</code>  for the specified message type.
-    * 
+    * Sends a message to an address. specified in {@link ClientSession#createProducer(String)} or
+    * similar methods. <br>
+    * <br>
+    * This will block until confirmation that the message has reached the server has been received
+    * if {@link ServerLocator#setBlockOnDurableSend(boolean)} or
+    * {@link ServerLocator#setBlockOnNonDurableSend(boolean)} are set to <code>true</code> for the
+    * specified message type.
     * @param message the message to send
     * @throws HornetQException if an exception occurs while sending the message
     */
    void send(Message message) throws HornetQException;
 
    /**
-    * Sends a message to the specified address instead of the ClientProducer's address.
-    *
-    * <br><br>This will block until confirmation that the message has reached the server has been received if
-    * {@link ClientSessionFactory#setBlockOnDurableSend(boolean)} or {@link org.hornetq.api.core.client.ClientSessionFactory#setBlockOnNonDurableSend(boolean)}
-    * are set to true for the specified message type.
-    *
+    * Sends a message to the specified address instead of the ClientProducer's address. <br>
+    * <br>
+    * This will block until confirmation that the message has reached the server has been received
+    * if {@link ServerLocator#setBlockOnDurableSend(boolean)} or
+    * {@link ServerLocator#setBlockOnNonDurableSend(boolean)} are set to true for the specified
+    * message type.
     * @param address the address where the message will be sent
     * @param message the message to send
     * @throws HornetQException if an exception occurs while sending the message
@@ -75,12 +76,12 @@
    void send(SimpleString address, Message message) throws HornetQException;
 
    /**
-    * Sends a message to the specified address instead of the ClientProducer's address.
-    *
-    * <br><br>This will block until confirmation that the message has reached the server has been received if
-    * {@link ClientSessionFactory#setBlockOnDurableSend(boolean)} or {@link org.hornetq.api.core.client.ClientSessionFactory#setBlockOnNonDurableSend(boolean)}
-    * are set to true for the specified message type.
-    *
+    * Sends a message to the specified address instead of the ClientProducer's address. <br>
+    * <br>
+    * This will block until confirmation that the message has reached the server has been received
+    * if {@link ServerLocator#setBlockOnDurableSend(boolean)} or
+    * {@link ServerLocator#setBlockOnNonDurableSend(boolean)} are set to true for the specified
+    * message type.
     * @param address the address where the message will be sent
     * @param message the message to send
     * @throws HornetQException if an exception occurs while sending the message
@@ -89,35 +90,35 @@
 
    /**
     * Closes the ClientProducer. If already closed nothing is done.
-    * 
+    *
     * @throws HornetQException if an exception occurs while closing the producer
     */
    void close() throws HornetQException;
 
    /**
     * Returns whether the producer is closed or not.
-    * 
+    *
     * @return <code>true</code> if the producer is closed, <code>false</code> else
     */
    boolean isClosed();
 
    /**
     * Returns whether the producer will block when sending <em>durable</em> messages.
-    * 
+    *
     * @return <code>true</code> if the producer blocks when sending durable, <code>false</code> else
     */
    boolean isBlockOnDurableSend();
 
    /**
     * Returns whether the producer will block when sending <em>non-durable</em> messages.
-    * 
+    *
     * @return <code>true</code> if the producer blocks when sending non-durable, <code>false</code> else
     */
    boolean isBlockOnNonDurableSend();
 
    /**
     * Returns the maximum rate at which a ClientProducer can send messages per second.
-    * 
+    *
     * @return the producers maximum rate
     */
    int getMaxRate();

Modified: trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/HornetQClient.java
===================================================================
--- trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/HornetQClient.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/HornetQClient.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -19,11 +19,11 @@
 
 /**
  * Utility class for creating HornetQ {@link ClientSessionFactory} objects.
- * 
+ *
  * Once a {@link ClientSessionFactory} has been created, it can be further configured
  * using its setter methods before creating the sessions. Once a session is created,
  * the factory can no longer be modified (its setter methods will throw a {@link IllegalStateException}.
- * 
+ *
  * @author <a href="mailto:andy.taylor at jboss.org">Andy Taylor</a>
  */
 public class HornetQClient
@@ -37,9 +37,9 @@
    public static final long DEFAULT_CONNECTION_TTL = 1 * 60 * 1000;
 
    // Any message beyond this size is considered a large message (to be sent in chunks)
-   
+
    public static final int DEFAULT_MIN_LARGE_MESSAGE_SIZE = 100 * 1024;
-   
+
    public static final boolean DEFAULT_COMPRESS_LARGE_MESSAGES = false;
 
    public static final int DEFAULT_CONSUMER_WINDOW_SIZE = 1024 * 1024;
@@ -81,7 +81,7 @@
    public static final int DEFAULT_RECONNECT_ATTEMPTS = 0;
 
    public static final int INITIAL_CONNECT_ATTEMPTS = 1;
-   
+
    public static final boolean DEFAULT_FAILOVER_ON_INITIAL_CONNECTION = false;
 
    public static final boolean DEFAULT_IS_HA = false;
@@ -97,13 +97,13 @@
    public static final int DEFAULT_INITIAL_MESSAGE_PACKET_SIZE = 1500;
 
    public static final boolean DEFAULT_XA = false;
-   
+
    public static final boolean DEFAULT_HA = false;
-   
+
    /**
     * Create a ServerLocator which creates session factories using a static list of transportConfigurations, the ServerLocator is not updated automatically
     * as the cluster topology changes, and no HA backup information is propagated to the client
-    * 
+    *
     * @param transportConfigurations
     * @return the ServerLocator
     */
@@ -111,12 +111,12 @@
    {
       return new ServerLocatorImpl(false, transportConfigurations);
    }
-   
+
    /**
     * Create a ServerLocator which creates session factories from a set of live servers, no HA backup information is propagated to the client
-    * 
+    *
     * The UDP address and port are used to listen for live servers in the cluster
-    * 
+    *
     * @param discoveryAddress The UDP group address to listen for updates
     * @param discoveryPort the UDP port to listen for updates
     * @return the ServerLocator
@@ -125,27 +125,39 @@
    {
       return new ServerLocatorImpl(false, groupConfiguration);
    }
-   
+
    /**
-    * Create a ServerLocator which will receive cluster topology updates from the cluster as servers leave or join and new backups are appointed or removed.
-    * The initial list of servers supplied in this method is simply to make an initial connection to the cluster, once that connection is made, up to date
-    * cluster topology information is downloaded and automatically updated whenever the cluster topology changes. If the topology includes backup servers
-    * that information is also propagated to the client so that it can know which server to failover onto in case of live server failure.
-    * @param initialServers The initial set of servers used to make a connection to the cluster. Each one is tried in turn until a successful connection is made. Once
-    * a connection is made, the cluster topology is downloaded and the rest of the list is ignored.
+    * Create a ServerLocator which will receive cluster topology updates from the cluster as servers
+    * leave or join and new backups are appointed or removed.
+    * <p>
+    * The initial list of servers supplied in this method is simply to make an initial connection to
+    * the cluster, once that connection is made, up to date cluster topology information is
+    * downloaded and automatically updated whenever the cluster topology changes.
+    * <p>
+    * If the topology includes backup servers that information is also propagated to the client so
+    * that it can know which server to failover onto in case of live server failure.
+    * @param initialServers The initial set of servers used to make a connection to the cluster.
+    *           Each one is tried in turn until a successful connection is made. Once a connection
+    *           is made, the cluster topology is downloaded and the rest of the list is ignored.
     * @return the ServerLocator
     */
    public static ServerLocator createServerLocatorWithHA(TransportConfiguration... initialServers)
    {
       return new ServerLocatorImpl(true, initialServers);
    }
-   
+
    /**
-    * Create a ServerLocator which will receive cluster topology updates from the cluster as servers leave or join and new backups are appointed or removed.
-    * The discoveryAddress and discoveryPort parameters in this method are used to listen for UDP broadcasts which contain connection information for members of the cluster.
-    * The broadcasted connection information is simply used to make an initial connection to the cluster, once that connection is made, up to date
-    * cluster topology information is downloaded and automatically updated whenever the cluster topology changes. If the topology includes backup servers
-    * that information is also propagated to the client so that it can know which server to failover onto in case of live server failure.
+    * Create a ServerLocator which will receive cluster topology updates from the cluster as servers
+    * leave or join and new backups are appointed or removed.
+    * <p>
+    * The discoveryAddress and discoveryPort parameters in this method are used to listen for UDP
+    * broadcasts which contain connection information for members of the cluster. The broadcasted
+    * connection information is simply used to make an initial connection to the cluster, once that
+    * connection is made, up to date cluster topology information is downloaded and automatically
+    * updated whenever the cluster topology changes.
+    * <p>
+    * If the topology includes backup servers that information is also propagated to the client so
+    * that it can know which server to failover onto in case of live server failure.
     * @param discoveryAddress The UDP group address to listen for updates
     * @param discoveryPort the UDP port to listen for updates
     * @return the ServerLocator
@@ -154,8 +166,8 @@
    {
       return new ServerLocatorImpl(true, groupConfiguration);
    }
-   
 
+
    private HornetQClient()
    {
    }

Modified: trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ServerLocator.java
===================================================================
--- trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ServerLocator.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-core/src/main/java/org/hornetq/api/core/client/ServerLocator.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -29,7 +29,7 @@
 
    /**
     * Returns true if close was already called
-    * @return
+    * @return {@code true} if closed, {@code false} otherwise.
     */
    boolean isClosed();
 

Modified: trunk/hornetq-jms/src/main/java/org/hornetq/api/jms/management/ConnectionFactoryControl.java
===================================================================
--- trunk/hornetq-jms/src/main/java/org/hornetq/jms/client/HornetQConnectionFactory.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-jms/src/main/java/org/hornetq/jms/client/HornetQConnectionFactory.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -552,10 +552,9 @@
    {
       return JMSFactoryType.CF.intValue();
    }
+   
    /**
-    *
     * @deprecated use {@link ServerLocator#createSessionFactory()}
-    * @return
     */
    @Deprecated
    public ClientSessionFactory getCoreFactory() throws JMSException



More information about the hornetq-commits mailing list
--- trunk/hornetq-jms/src/main/java/org/hornetq/api/jms/management/ConnectionFactoryControl.java	2012-01-23 12:01:08 UTC (rev 12044)
+++ trunk/hornetq-jms/src/main/java/org/hornetq/api/jms/management/ConnectionFactoryControl.java	2012-01-23 12:01:43 UTC (rev 12045)
@@ -16,18 +16,17 @@
 import org.hornetq.api.core.DiscoveryGroupConfiguration;
 import org.hornetq.api.core.TransportConfiguration;
 import org.hornetq.api.core.client.ClientSessionFactory;
+import org.hornetq.api.core.client.ServerLocator;
 import org.hornetq.api.core.management.Operation;
 import org.hornetq.api.core.management.Parameter;
 
 /**
- * A ConnectionFactoryControl is used to manage a JMS ConnectionFactory.
- * <br>
- * HornetQ JMS ConnectionFactory uses an underlying ClientSessionFactory to connect to HornetQ servers.
- * Please refer to the ClientSessionFactory for a detailed description.
- * 
+ * A ConnectionFactoryControl is used to manage a JMS ConnectionFactory. <br>
+ * HornetQ JMS ConnectionFactory uses an underlying ClientSessionFactory to connect to HornetQ
+ * servers. Please refer to the ClientSessionFactory for a detailed description.
  * @author <a href="mailto:jmesnil at redhat.com">Jeff Mesnil</a>
  * @author <a href="mailto:fox at redhat.com">Tim Fox</a>
- * 
+ * @see ServerLocator
  * @see ClientSessionFactory
  */
 public interface ConnectionFactoryControl
@@ -63,290 +62,289 @@
    * Sets the Client ID for this connection factory.
    */
    void setClientID(String clientID);
-   
+
    boolean isCompressLargeMessages();
-   
+
    void setCompressLargeMessages(boolean compress);
 
    /**
-    * @see ClientSessionFactory#getClientFailureCheckPeriod()
+    * @see ServerLocator#getClientFailureCheckPeriod()
     */
    long getClientFailureCheckPeriod();
 
    /**
-    * @see ClientSessionFactory#setClientFailureCheckPeriod
+    * @see ServerLocator#setClientFailureCheckPeriod
     */
    void setClientFailureCheckPeriod(long clientFailureCheckPeriod);
 
    /**
-    * @see ClientSessionFactory#getCallTimeout()
+    * @see ServerLocator#getCallTimeout()
     */
    long getCallTimeout();
 
    /**
-    * @see ClientSessionFactory#setCallTimeout(long)
+    * @see ServerLocator#setCallTimeout(long)
     */
    void setCallTimeout(long callTimeout);
 
    /**
     * Returns the batch size (in bytes) between acknowledgements when using DUPS_OK_ACKNOWLEDGE mode.
     * 
     * @see ClientSessionFactory#getAckBatchSize()
     * @see javax.jms.Session#DUPS_OK_ACKNOWLEDGE
     */
    int getDupsOKBatchSize();
 
    /**
-    * @see ClientSessionFactory#setAckBatchSize(int)
+    * @see ServerLocator#setAckBatchSize(int)
     */
    void setDupsOKBatchSize(int dupsOKBatchSize);
 
    /**
-    * @see ClientSessionFactory#getConsumerMaxRate()
+    * @see ServerLocator#getConsumerMaxRate()
     */
    int getConsumerMaxRate();
 
    /**
-    * @see ClientSessionFactory#setConsumerMaxRate(int)
+    * @see ServerLocator#setConsumerMaxRate(int)
     */
    void setConsumerMaxRate(int consumerMaxRate);
 
    /**
-    * @see ClientSessionFactory#getConsumerWindowSize()
+    * @see ServerLocator#getConsumerWindowSize()
     */
    int getConsumerWindowSize();
 
    /**
-    * @see ClientSessionFactory#setConfirmationWindowSize(int)
+    * @see ServerLocator#setConfirmationWindowSize(int)
     */
    void setConsumerWindowSize(int consumerWindowSize);
 
    /**
-    * @see ClientSessionFactory#getProducerMaxRate()
+    * @see ServerLocator#getProducerMaxRate()
     */
    int getProducerMaxRate();
 
    /**
-    * @see ClientSessionFactory#setProducerMaxRate(int)
+    * @see ServerLocator#setProducerMaxRate(int)
     */
    void setProducerMaxRate(int producerMaxRate);
 
    /**
-    * @see ClientSessionFactory#getConfirmationWindowSize()
+    * @see ServerLocator#getConfirmationWindowSize()
     */
    int getConfirmationWindowSize();
 
     /**
-    * @see ClientSessionFactory#setConfirmationWindowSize(int)
+    * @see ServerLocator#setConfirmationWindowSize(int)
     */
    void setConfirmationWindowSize(int confirmationWindowSize);
 
    /**
-    * @see ClientSessionFactory#isBlockOnAcknowledge()
+    * @see ServerLocator#isBlockOnAcknowledge()
     */
    boolean isBlockOnAcknowledge();
 
     /**
-    * @see ClientSessionFactory#setBlockOnAcknowledge(boolean)
+    * @see ServerLocator#setBlockOnAcknowledge(boolean)
     */
    void setBlockOnAcknowledge(boolean blockOnAcknowledge);
 
    /**
-    * @see ClientSessionFactory#isBlockOnDurableSend()
+    * @see ServerLocator#isBlockOnDurableSend()
     */
    boolean isBlockOnDurableSend();
 
     /**
-    * @see ClientSessionFactory#setBlockOnDurableSend(boolean)
+    * @see ServerLocator#setBlockOnDurableSend(boolean)
     */
    void setBlockOnDurableSend(boolean blockOnDurableSend);
 
    /**
-    * @see ClientSessionFactory#isBlockOnNonDurableSend()
+    * @see ServerLocator#isBlockOnNonDurableSend()
     */
    boolean isBlockOnNonDurableSend();
 
     /**
-    * @see ClientSessionFactory#setBlockOnNonDurableSend(boolean)
+    * @see ServerLocator#setBlockOnNonDurableSend(boolean)
     */
    void setBlockOnNonDurableSend(boolean blockOnNonDurableSend);
 
    /**
-    * @see ClientSessionFactory#isPreAcknowledge()
+    * @see ServerLocator#isPreAcknowledge()
     */
    boolean isPreAcknowledge();
 
     /**
-    * @see ClientSessionFactory#setPreAcknowledge(boolean)
+    * @see ServerLocator#setPreAcknowledge(boolean)
     */
    void setPreAcknowledge(boolean preAcknowledge);
 
 
    /**
-    * @see ClientSessionFactory#getConnectionTTL()
+    * @see ServerLocator#getConnectionTTL()
     */
    long getConnectionTTL();
 
     /**
-    * @see ClientSessionFactory#setConnectionTTL(long)
+    * @see ServerLocator#setConnectionTTL(long)
     */
    void setConnectionTTL(long connectionTTL);
 
    /**
     * Returns the batch size (in bytes) between acknowledgements when using a transacted session.
-    * 
-    * @see ClientSessionFactory#getAckBatchSize()
+    * @see ServerLocator#getAckBatchSize()
     */
    int getTransactionBatchSize();
 
     /**
-    * @see ClientSessionFactory#setAckBatchSize(int)
+    * @see ServerLocator#setAckBatchSize(int)
     */
    void setTransactionBatchSize(int transactionBatchSize);
 
    /**
-    * @see ClientSessionFactory#getMinLargeMessageSize()
+    * @see ServerLocator#getMinLargeMessageSize()
     */
    int getMinLargeMessageSize();
 
     /**
-    * @see ClientSessionFactory#setMinLargeMessageSize(int)
+    * @see ServerLocator#setMinLargeMessageSize(int)
     */
    void setMinLargeMessageSize(int minLargeMessageSize);
 
    /**
-    * @see ClientSessionFactory#isAutoGroup()
+    * @see ServerLocator#isAutoGroup()
     */
    boolean isAutoGroup();
 
     /**
-    * @see ClientSessionFactory#setAutoGroup(boolean)
+    * @see ServerLocator#setAutoGroup(boolean)
     */
    void setAutoGroup(boolean autoGroup);
 
    /**
-    * @see ClientSessionFactory#getRetryInterval()
+    * @see ServerLocator#getRetryInterval()
     */
    long getRetryInterval();
 
     /**
-    * @see ClientSessionFactory#setRetryInterval(long)
+    * @see ServerLocator#setRetryInterval(long)
     */
    void setRetryInterval(long retryInterval);
 
    /**
-    * @see ClientSessionFactory#getRetryIntervalMultiplier()
+    * @see ServerLocator#getRetryIntervalMultiplier()
     */
    double getRetryIntervalMultiplier();
 
     /**
-    * @see ClientSessionFactory#setRetryIntervalMultiplier(double)
+    * @see ServerLocator#setRetryIntervalMultiplier(double)
     */
    void setRetryIntervalMultiplier(double retryIntervalMultiplier);
 
    /**
-    * @see ClientSessionFactory#getReconnectAttempts()
+    * @see ServerLocator#getReconnectAttempts()
     */
    int getReconnectAttempts();
 
     /**
-    * @see ClientSessionFactory#setReconnectAttempts(int)
+    * @see ServerLocator#setReconnectAttempts(int)
     */
    void setReconnectAttempts(int reconnectAttempts);
-   
+
    /**
-    * @see ClientSessionFactory#isFailoverOnInitialConnection()
+    * @see ServerLocator#isFailoverOnInitialConnection()
     */
    boolean isFailoverOnInitialConnection();
 
     /**
-    * @see ClientSessionFactory#setFailoverOnInitialConnection(boolean)
+    * @see ServerLocator#setFailoverOnInitialConnection(boolean)
     */
    void setFailoverOnInitialConnection(boolean failoverOnInitialConnection);
 
 
     /**
-    * @see org.hornetq.api.core.client.ClientSessionFactory#getProducerWindowSize()
+    * @see org.hornetq.api.core.client.ServerLocator#getProducerWindowSize()
     */
    int getProducerWindowSize();
 
     /**
-    * @see ClientSessionFactory#setProducerWindowSize(int)
+    * @see ServerLocator#setProducerWindowSize(int)
     */
    void setProducerWindowSize(int producerWindowSize);
 
     /**
-    * @see ClientSessionFactory#isCacheLargeMessagesClient()
+    * @see ServerLocator#isCacheLargeMessagesClient()
     */
    boolean isCacheLargeMessagesClient();
 
     /**
-    * @see ClientSessionFactory#setCacheLargeMessagesClient(boolean)
+    * @see ServerLocator#setCacheLargeMessagesClient(boolean)
     */
    void setCacheLargeMessagesClient(boolean cacheLargeMessagesClient);
 
     /**
-    * @see ClientSessionFactory#getMaxRetryInterval()
+    * @see ServerLocator#getMaxRetryInterval()
     */
    long getMaxRetryInterval();
 
     /**
-    * @see ClientSessionFactory#setMaxRetryInterval(long)
+    * @see ServerLocator#setMaxRetryInterval(long)
     */
    void setMaxRetryInterval(long retryInterval);
 
     /**
-    * @see ClientSessionFactory#getScheduledThreadPoolMaxSize()
+    * @see ServerLocator#getScheduledThreadPoolMaxSize()
     */
    int getScheduledThreadPoolMaxSize();
 
     /**
-    * @see ClientSessionFactory#setScheduledThreadPoolMaxSize(int)
+    * @see ServerLocator#setScheduledThreadPoolMaxSize(int)
     */
    void setScheduledThreadPoolMaxSize(int scheduledThreadPoolMaxSize);
 
     /**
-    * @see ClientSessionFactory#getThreadPoolMaxSize()
+    * @see ServerLocator#getThreadPoolMaxSize()
     */
    int getThreadPoolMaxSize();
 
     /**
-    * @see ClientSessionFactory#setThreadPoolMaxSize(int)
+    * @see ServerLocator#setThreadPoolMaxSize(int)
     */
    void setThreadPoolMaxSize(int threadPoolMaxSize);
 
     /**
-    * @see ClientSessionFactory#getGroupID()
+    * @see ServerLocator#getGroupID()
     */
    String getGroupID();
 
     /**
-    * @see ClientSessionFactory#setGroupID(String)
+    * @see ServerLocator#setGroupID(String)
     */
    void setGroupID(String groupID);
 
     /**
-    * @see ClientSessionFactory#getInitialMessagePacketSize()
+    * @see ServerLocator#getInitialMessagePacketSize()
     */
    int getInitialMessagePacketSize();
 
     /**
-    * @see ClientSessionFactory#isUseGlobalPools()
+    * @see ServerLocator#isUseGlobalPools()
     */
    boolean isUseGlobalPools();
 
     /**
-    * @see ClientSessionFactory#setUseGlobalPools(boolean)
+    * @see ServerLocator#setUseGlobalPools(boolean)
     */
    void setUseGlobalPools(boolean useGlobalPools);
 
     /**
-    * @see ClientSessionFactory#getConnectionLoadBalancingPolicyClassName()
+    * @see ServerLocator#getConnectionLoadBalancingPolicyClassName()
     */
    String getConnectionLoadBalancingPolicyClassName();
 
     /**
-    * @see ClientSessionFactory#setConnectionLoadBalancingPolicyClassName(String)
+    * @see ServerLocator#setConnectionLoadBalancingPolicyClassName(String)
     */
    void setConnectionLoadBalancingPolicyClassName(String connectionLoadBalancingPolicyClassName);
 
@@ -63,290 +62,289 @@
 
    /**
-    * Returns the batch size (in bytes) between acknowledgements when using DUPS_OK_ACKNOWLEDGE mode.
-    * 
-    * @see ClientSessionFactory#getAckBatchSize()
+    * Returns the batch size (in bytes) between acknowledgements when using DUPS_OK_ACKNOWLEDGE
+    * mode.
+    * @see ServerLocator#getAckBatchSize()
     * @see javax.jms.Session#DUPS_OK_ACKNOWLEDGE
     */

Modified: trunk/hornetq-jms/src/main/java/org/hornetq/jms/client/HornetQConnectionFactory.java
===================================================================